@@ -82,7 +82,7 @@ extract_here_callback (NautilusMenuItem *item,
 	dir = nautilus_file_info_get_parent_uri (file);
 
 	cmd = g_string_new ("file-roller");
-	g_string_append_printf (cmd," --extract-here");
+	g_string_append_printf (cmd," --extract-here --notify");
 
 	g_free (dir);
 
