@@ -78,6 +78,8 @@ FrMimeTypeDescription mime_type_desc[] = {
 	{ "application/x-compressed-tar",       ".tar.gz",   0 },
 	{ "application/x-cpio",                 ".cpio",     0 },
 	{ "application/x-deb",                  ".deb",      0 },
+	{ "application/x-debian-package",	".deb",      0 },
+	{ "application/vnd.debian.binary-package",	".deb",      0 },
 	{ "application/x-ear",                  ".ear",      0 },
 	{ "application/x-ms-dos-executable",    ".exe",      0 },
 	{ "application/x-gzip",                 ".gz",       0 },
@@ -120,6 +122,7 @@ FrExtensionType file_ext_type[] = {
 	{ ".cab", "application/vnd.ms-cab-compressed" },
 	{ ".cbr", "application/x-cbr" },
 	{ ".cbz", "application/x-cbz" },
+	{ ".click", "application/x-deb" },
 	{ ".cpio", "application/x-cpio" },
 	{ ".deb", "application/x-deb" },
 	{ ".ear", "application/x-ear" },
